changed_files_against_in

Function changed_files_against_in 

pub fn changed_files_against_in(
    dir: &Path,
    reference: &str,
) -> Result<HashSet<String>>
Dir-explicit variant of changed_files_against, for commands and tests that operate on an explicit project root instead of the process cwd.