pub struct Indexer {
pub db: Database,
/* private fields */
}Expand description
Indexer for building the code intelligence database.
Fields
db: DatabaseThe database connection (pub for watch mode access).
Implementations
Sourceimpl Indexer
impl Indexer
Sourcepub fn with_config(
root: &Path,
verbose: bool,
walker_config: WalkerConfig,
) -> Result<Self>
pub fn with_config( root: &Path, verbose: bool, walker_config: WalkerConfig, ) -> Result<Self>
Create a new indexer with custom walker configuration.
Sourcepub fn new_in_memory(root: &Path) -> Result<Self>
pub fn new_in_memory(root: &Path) -> Result<Self>
Create an indexer with an in-memory database (for testing).
Sourcepub fn index(&mut self) -> Result<IndexResult>
pub fn index(&mut self) -> Result<IndexResult>
Index the codebase.
Sourcepub fn index_parallel(&mut self) -> Result<IndexResult>
pub fn index_parallel(&mut self) -> Result<IndexResult>
Index the codebase using parallel parsing.
This method uses rayon to parse files in parallel, then batch-inserts the results into the database. This is significantly faster for large codebases on multi-core systems.
Sourcepub fn index_file(&mut self, path: &Path) -> Result<bool>
pub fn index_file(&mut self, path: &Path) -> Result<bool>
Index a single file.