pub struct CompiledRules {
pub file: RulesFile,
/* private fields */
}Expand description
A RulesFile with all glob patterns compiled.
Fields
file: RulesFileImplementations
Sourceimpl CompiledRules
impl CompiledRules
Sourcepub fn compile(file: RulesFile) -> Result<Self>
pub fn compile(file: RulesFile) -> Result<Self>
Compile all glob patterns in file.
Fails on unsupported versions and invalid glob patterns.
Sourcepub fn layer_of(&self, path: &str) -> Option<&str>
pub fn layer_of(&self, path: &str) -> Option<&str>
The layer path belongs to, or None if it matches no layer.
Self::validate guarantees indexed files match at most one layer.
Sourcepub fn layers_of(&self, path: &str) -> Vec<&str>
pub fn layers_of(&self, path: &str) -> Vec<&str>
All layers path belongs to (used for overlap detection).
Sourcepub fn validate(&self, indexed_files: &[String]) -> Result<()>
pub fn validate(&self, indexed_files: &[String]) -> Result<()>
Validate the rules against the set of indexed files.
Errors on:
- rules referencing undeclared layer names
- an indexed file matching two or more layers
metric = "file_symbols"combined withscope = "symbol"
Sourcepub fn limit_exclude(&self, i: usize) -> &GlobSet
pub fn limit_exclude(&self, i: usize) -> &GlobSet
Compiled exclude globset for file.rules.limit[i].
Sourcepub fn frozen_path(&self, i: usize) -> &GlobSet
pub fn frozen_path(&self, i: usize) -> &GlobSet
Compiled paths globset for file.rules.no_new_dependents[i].