smart_context_with_embedding

Function smart_context_with_embedding 

pub fn smart_context_with_embedding(
    db: &Database,
    analytics: &Analytics,
    task: &str,
    task_embedding: &Embedding,
    config: SmartConfig,
) -> Result<SmartContext>
Select files relevant to a task using a pre-computed embedding.

This variant is useful when the embedding has been computed asynchronously (e.g., in the MCP server with OpenAI’s async API) to avoid blocking the async runtime.

See smart_context for the full algorithm description.