Module utils

Module utils 

Shared utility functions for ctx.

This module contains helper functions used across multiple command modules.

Functions

lexical_tokens
Split a string into normalized lexical tokens for path / identifier matching.
truncate_path
Truncate a path from the beginning, respecting UTF-8 char boundaries.
truncate_str
Truncate a string with ellipsis, respecting UTF-8 char boundaries.